"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transpile = void 0;
const yargs_1 = require("yargs");
const helpers_1 = require("yargs/helpers");
const compiler_dom_1 = require("@vue/compiler-dom");
const fs_1 = require("fs");
async function transpile() {
    const options = await getOptions();
    const inputStream = (0, fs_1.createReadStream)(options.infile);
    const outputStream = (0, fs_1.createWriteStream)(options.outfile);
    const template = await streamToString(inputStream);
    const isCustomElement = await isCustomElementFn(options);
    const compilerOptions = { isCustomElement, mode: options.mode };
    const codeGen = (0, compiler_dom_1.compile)(template, compilerOptions);
    const code = codeGen.code;
    outputStream.write(code);
    outputStream.close();
}
exports.transpile = transpile;
function isCustomElementFn(options) {
    if (options.customElementRegexp) {
        const re = new RegExp(options.customElementRegexp);
        return (tag) => re.test(tag);
    }
    else {
        return () => false;
    }
}
function getOptions() {
    const args = (0, helpers_1.hideBin)(process.argv);
    return (0, yargs_1.default)(args)
        .usage("$0", "Compile vue templates to render functions.")
        .options({
        infile: {
            description: "Template file to be compiled",
            type: "string",
            demandOption: true,
            requiresArg: true
        },
        outfile: {
            description: "Destination file",
            type: "string",
            demandOption: true,
            requiresArg: true
        },
        'custom-element-regexp': {
            type: "string",
            description: "Regular expression to match custom elements"
        },
        mode: {
            type: "string",
            choices: ["module", "function"],
            default: "function",
            description: "Generate an module exporting the render function or a simple function"
        }
    })
        .parse();
}
function streamToString(stream) {
    const chunks = [];
    return new Promise(function (resolve, reject) {
        stream.on('data', function (chunk) {
            chunks.push(Buffer.from(chunk));
        });
        stream.on('error', (err) => reject(err));
        stream.on('end', function () {
            const fileBuffer = Buffer.concat(chunks);
            const file = fileBuffer.toString('utf8');
            resolve(file);
        });
    });
}
